Работа с кукисами — Grab 0.6.30 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Grab 0.6.30 documentation »

# Работа с кукисами

## Настройка кукисов

Для того, чтобы отправить в запросе кукисы, используйте опцию cookies. Для того, чтобы кукисы, полученные в ответе сервера, автоматически подставлялись в следующие запросы, используйте опцию reuse_cookies. По-умолчанию, она включена.

Если включены обе опции cookies и reuse_cookies, то запомненные кукисы будут объединяться с теми, что указаны в cookies.

## Работа с файлом кукисов

Вы можете указать путь к файлу в опции cookiefile. Перед каждым запросом Grab будет считывать кукисы из этого файла и объединять с теми, что он уже помнит. После каждого запроса, Grab будет сохранять все кукисы в указанный файл. Эта опция полезна, если вам нужно сохранить сессию авторизованного пользователя между различными запусками программы. Формат данных в файле: JSON-сериализованный словарь.

Для того, чтобы выгрузить кукисы Grab-объекта в файл, используйте метод dump_cookies. Для загрузки кукисов из файла используйте load_cookies.

Если вам нужно очистить все запомненные кукисы, воспользуйтесь методом clear_cookies, конкретно, он обнулит опцию cookies. Однако помните, если вы задали опцию cookiefile, то для следующего запроса, кукисы повторно загрузятся из этого файла.

### Navigation

- index
- modules |
- next |
- previous |
- Grab 0.6.30 documentation »